[![](https://img.shields.io/github/v/tag/bioexcel/biobb_common?label=Version)](https://GitHub.com/bioexcel/biobb_common/tags/)
[![](https://img.shields.io/pypi/v/biobb-common.svg?label=Pypi)](https://pypi.python.org/pypi/biobb-common/)
[![](https://img.shields.io/conda/vn/bioconda/biobb_common?label=Conda)](https://anaconda.org/bioconda/biobb_common)
[![](https://img.shields.io/conda/dn/bioconda/biobb_common?label=Conda%20Downloads)](https://anaconda.org/bioconda/biobb_common)
[![](https://img.shields.io/badge/Docker-Quay.io-blue)](https://quay.io/repository/biocontainers/biobb_common?tab=tags)
[![](https://img.shields.io/badge/Singularity-GalaxyProject-blue)](https://depot.galaxyproject.org/singularity/biobb_common:5.2.1--pyhdfd78af_0)

[![](https://img.shields.io/badge/OS-Unix%20%7C%20MacOS-blue)]()
[![](https://img.shields.io/pypi/pyversions/biobb-common.svg?label=Python%20Versions)]()
[![](https://img.shields.io/badge/License-Apache%202.0-blue.svg)](https://opensource.org/licenses/Apache-2.0)
[![](https://img.shields.io/badge/Open%20Source%3f-Yes!-blue)]()

[![](https://readthedocs.org/projects/biobb-common/badge/?version=latest&label=Docs)](https://biobb-common.readthedocs.io/en/latest/?badge=latest)
[![](https://img.shields.io/website?down_message=Offline&label=Biobb%20Website&up_message=Online&url=https%3A%2F%2Fmmb.irbbarcelona.org%2Fbiobb%2F)]()
[![](https://img.shields.io/badge/Youtube-tutorials-blue?logo=youtube&logoColor=red)](https://www.youtube.com/@BioExcelCoE/search?query=biobb)
[![](https://zenodo.org/badge/DOI/10.1038/s41597-019-0177-4.svg)](https://doi.org/10.1038/s41597-019-0177-4)
[![](https://img.shields.io/endpoint?color=brightgreen&url=https%3A%2F%2Fapi.juleskreuer.eu%2Fcitation-badge.php%3Fshield%26doi%3D10.1038%2Fs41597-019-0177-4)](https://www.nature.com/articles/s41597-019-0177-4#citeas)

[![](https://img.shields.io/badge/Tests-Passing-brightgreen)]()
[![](https://img.shields.io/badge/Coverage-90%25-brightgreen)]()
[![](https://img.shields.io/github/last-commit/bioexcel/biobb_common?label=Last%20Commit)]()
[![](https://img.shields.io/github/issues/bioexcel/biobb_common.svg?color=brightgreen&label=Issues)](https://GitHub.com/bioexcel/biobb_common/issues/)



# biobb_common

### Introduction
Biobb_common is the base package required to use the biobb
packages.
Biobb (BioExcel building blocks) packages are Python building blocks that
create new layer of compatibility and interoperability over popular
bioinformatics tools.
The latest documentation of this package can be found in our readthedocs site:
[latest API documentation](http://biobb-common.readthedocs.io/en/latest/).

### Version
v5.2.1 2025.2

### Copyright & Licensing
This software has been developed in the [MMB group](http://mmb.irbbarcelona.org) at the [BSC](http://www.bsc.es/) & [IRB](https://www.irbbarcelona.org/) for the [European BioExcel](http://bioexcel.eu/), funded by the European Commission (EU Horizon Europe [101093290](https://cordis.europa.eu/project/id/101093290), EU H2020 [823830](http://cordis.europa.eu/projects/823830), EU H2020 [675728](http://cordis.europa.eu/projects/675728)).

* (c) 2015-2026 [Barcelona Supercomputing Center](https://www.bsc.es/)
* (c) 2015-2026 [Institute for Research in Biomedicine](https://www.irbbarcelona.org/)

Licensed under the
[Apache License 2.0](https://www.apache.org/licenses/LICENSE-2.0), see the file LICENSE for details.

![](https://bioexcel.eu/wp-content/uploads/2019/04/Bioexcell_logo_1080px_transp.png "Bioexcel")
